@@ -69,7 +69,7 @@ zenity_forms_create_and_fill_combo (ZenityFormsData *forms_data,
 
 	if (forms_data->combo_values)
 	{
-		g_autofree char *combo_values =
+		char *combo_values =
 			g_slist_nth_data (forms_data->combo_values, combo_number);
 
 		if (combo_values)
@@ -157,7 +157,7 @@ zenity_forms_create_and_fill_list (ZenityFormsData *forms_data,
 
 	if (forms_data->list_values)
 	{
-		g_autofree char *list_values =
+		char *list_values =
 			g_slist_nth_data (forms_data->list_values, list_number);
 
 		if (list_values)
@@ -232,8 +232,7 @@ zenity_forms_dialog (ZenityData *data, ZenityFormsData *forms_data)
 	g_signal_connect (dialog, "response",
 		G_CALLBACK (zenity_forms_dialog_response), forms_data);
 
-	if (data->dialog_title)
-		adw_message_dialog_set_heading (ADW_MESSAGE_DIALOG(dialog), data->dialog_title);;
+	zenity_util_setup_dialog_title (dialog, data);
 
 	if (data->width > -1 || data->height > -1) {
 		gtk_window_set_default_size (GTK_WINDOW(dialog),
@@ -305,6 +304,27 @@ zenity_forms_dialog (ZenityData *data, ZenityFormsData *forms_data)
 				combo_count++;
 				break;
 
+			case ZENITY_FORMS_MULTLINE_ENTRY:
+			{
+				GtkWidget *tv = gtk_text_view_new ();
+
+				zenity_value->forms_widget = gtk_scrolled_window_new ();
+				gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(zenity_value->forms_widget), tv);
+
+				/* Try to keep consistent with the properties set for
+				 * zenity_text_view in the .ui file (used with --text-info)
+				 */
+				gtk_widget_set_vexpand (zenity_value->forms_widget, TRUE);
+				gtk_text_view_set_editable (GTK_TEXT_VIEW(tv), TRUE);
+				gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(tv), GTK_WRAP_WORD);
+
+				/* Being able to insert tabs in a textview is nice, but NOT
+				 * being able to tab between widgets in forms is just annoying.
+				 */
+				gtk_text_view_set_accepts_tab (GTK_TEXT_VIEW(tv), FALSE);
+			}
+				break;
+
 			default:
 				zenity_value->forms_widget = gtk_entry_new ();
 				break;
@@ -404,6 +424,19 @@ zenity_forms_dialog_output (ZenityFormsData *forms_data)
 			}
 				break;
 
+			case ZENITY_FORMS_MULTLINE_ENTRY:
+			{
+				g_autofree char *text = NULL;
+				GtkWidget *tv = gtk_scrolled_window_get_child (GTK_SCROLLED_WINDOW(zenity_value->forms_widget));
+				GtkTextBuffer *buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(tv));
+				GtkTextIter start, end;
+
+				gtk_text_buffer_get_bounds (buffer, &start, &end);
+				text = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
+				g_print ("%s", text);
+			}
+				break;
+
 		}
 		if (tmp->next != NULL)
 			g_print ("%s", forms_data->separator);
